@@ -1338,9 +1338,9 @@ def get_action_args_with_defaults(action, args, defaults, templar, redirected_na
         'aws': ['amazon.aws', 'community.aws'],
         'azure': ['azure.azcollection'],
         'cpm': ['wti.remote'],
-        'docker': ['community.general'],
+        'docker': ['community.general', 'community.docker'],
         'gcp': ['google.cloud'],
-        'k8s': ['community.kubernetes', 'community.general'],
+        'k8s': ['community.kubernetes', 'community.general', 'community.kubevirt', 'community.okd', 'kubernetes.core'],
         'os': ['openstack.cloud'],
         'ovirt': ['ovirt.ovirt', 'community.general'],
         'vmware': ['community.vmware'],
