@@ -79,8 +79,9 @@ options:
         version_added: 2.2
 notes:
     - For AIX, group subsystem names can be used.
+    - Supports C(check_mode).
 seealso:
-- module: ansible.windows.win_service
+    - module: ansible.windows.win_service
 author:
     - Ansible Core Team
     - Michael DeHaan
@@ -88,43 +89,45 @@ author:
 
 EXAMPLES = r'''
 - name: Start service httpd, if not started
-  service:
+  ansible.builtin.service:
     name: httpd
     state: started
 
 - name: Stop service httpd, if started
-  service:
+  ansible.builtin.service:
     name: httpd
     state: stopped
 
 - name: Restart service httpd, in all cases
-  service:
+  ansible.builtin.service:
     name: httpd
     state: restarted
 
 - name: Reload service httpd, in all cases
-  service:
+  ansible.builtin.service:
     name: httpd
     state: reloaded
 
 - name: Enable service httpd, and not touch the state
-  service:
+  ansible.builtin.service:
     name: httpd
     enabled: yes
 
 - name: Start service foo, based on running process /usr/bin/foo
-  service:
+  ansible.builtin.service:
     name: foo
     pattern: /usr/bin/foo
     state: started
 
 - name: Restart network service for interface eth0
-  service:
+  ansible.builtin.service:
     name: network
     state: restarted
     args: eth0
 '''
 
+RETURN = r'''#'''
+
 import glob
 import json
 import os
