@@ -377,6 +377,16 @@ class PathMapper:
 
         minimal = {}
 
+        if os.path.sep not in path:
+            if filename in (
+                    'azure-pipelines.yml',
+                    'shippable.yml',
+            ):
+                return all_tests(self.args)  # test infrastructure, run all tests
+
+        if is_subdir(path, '.azure-pipelines'):
+            return all_tests(self.args)  # test infrastructure, run all tests
+
         if is_subdir(path, '.github'):
             return minimal
 
@@ -650,6 +660,9 @@ class PathMapper:
         if result is not None:
             return result
 
+        filename = os.path.basename(path)
+        dummy, ext = os.path.splitext(filename)
+
         minimal = {}
 
         if path.startswith('changelogs/'):
@@ -658,6 +671,24 @@ class PathMapper:
         if path.startswith('docs/'):
             return minimal
 
+        if '/' not in path:
+            if path in (
+                    '.gitignore',
+                    'COPYING',
+                    'LICENSE',
+                    'Makefile',
+            ):
+                return minimal
+
+            if ext in (
+                    '.in',
+                    '.md',
+                    '.rst',
+                    '.toml',
+                    '.txt',
+            ):
+                return minimal
+
         return None
 
     def _classify_ansible(self, path):  # type: (str) -> t.Optional[t.Dict[str, str]]
@@ -873,7 +904,6 @@ class PathMapper:
 
             if path in (
                     'setup.py',
-                    'shippable.yml',
             ):
                 return all_tests(self.args)  # broad impact, run all tests
 
